@@ -24,6 +24,26 @@
 #include "generalprefpage.h"
 #include "appconfig.h"
 
+#ifdef USE_MOUSE
+static void cb_mouse_switch( GtkWidget *item, gpointer data )
+{
+	AppConfig.WithMiddleButton = *((bool *) data);
+}
+
+static bool withMiddleButton = TRUE;
+static GtkWidget *make_menu_item ( const char *name, GCallback callback, bool withMB)
+{
+	GtkWidget *item;
+
+	item = gtk_menu_item_new_with_label (name);
+	withMiddleButton = withMB;
+	g_signal_connect (item, "activate", callback, (gpointer) &withMiddleButton);
+	gtk_widget_show (item);
+
+	return item;
+}
+#endif
+
 CGeneralPrefPage::CGeneralPrefPage()
  : CWidget()
 {
@@ -53,9 +73,25 @@ CGeneralPrefPage::CGeneralPrefPage()
 	gtk_box_pack_start (GTK_BOX (m_Widget), m_CancelSelAfterCopy, FALSE, FALSE, 0);
 
 #ifdef USE_MOUSE
+	GtkWidget *hboxMouse;
+	hboxMouse = gtk_hbox_new (FALSE, 0);
+	gtk_widget_show (hboxMouse);
+	gtk_box_pack_start (GTK_BOX (m_Widget), hboxMouse, FALSE, FALSE, 0);
+
 	m_MouseSupport = gtk_check_button_new_with_mnemonic (_("Enable Mouse Support"));
 	gtk_widget_show (m_MouseSupport);
-	gtk_box_pack_start (GTK_BOX (m_Widget), m_MouseSupport, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hboxMouse), m_MouseSupport, FALSE, FALSE, 0);
+
+	GtkWidget *opt, *menu, *item;
+	opt = gtk_option_menu_new ();
+	menu = gtk_menu_new ();
+	item = make_menu_item ("with middle button", G_CALLBACK (cb_mouse_switch), TRUE);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	item = make_menu_item ("without middle button", G_CALLBACK (cb_mouse_switch), FALSE);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	gtk_option_menu_set_menu (GTK_OPTION_MENU (opt), menu);
+	gtk_widget_show (opt);
+	gtk_box_pack_start (GTK_BOX (hboxMouse), opt, FALSE, FALSE, 0);
 #endif
 
 #ifdef USE_DOCKLET
@@ -64,13 +100,9 @@ CGeneralPrefPage::CGeneralPrefPage()
 	gtk_box_pack_start (GTK_BOX (m_Widget), m_ShowTrayIcon, FALSE, FALSE, 0);
 #endif
 
-	m_ShowToolbar = gtk_check_button_new_with_mnemonic (_("Show Toolbar"));
-	gtk_widget_show (m_ShowToolbar);
-	gtk_box_pack_start (GTK_BOX (m_Widget), m_ShowToolbar, FALSE, FALSE, 0);
-
-	m_ShowStatusBar = gtk_check_button_new_with_mnemonic (_("Show Status Bar on bottom"));
-	gtk_widget_show (m_ShowStatusBar);
-	gtk_box_pack_start (GTK_BOX (m_Widget), m_ShowStatusBar, FALSE, FALSE, 0);
+	m_ShowInSimpleMode = gtk_check_button_new_with_mnemonic (_("Start PCManX in simple mode"));
+	gtk_widget_show (m_ShowInSimpleMode);
+	gtk_box_pack_start (GTK_BOX (m_Widget), m_ShowInSimpleMode, FALSE, FALSE, 0);
 
 	m_AAFont = gtk_check_button_new_with_mnemonic (_("Use Anti-Aliasing Fonts (Take effect after restart)"));
 	gtk_widget_show (m_AAFont);
@@ -129,8 +161,7 @@ CGeneralPrefPage::CGeneralPrefPage()
 #ifdef USE_DOCKLET
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_ShowTrayIcon), AppConfig.ShowTrayIcon);
 #endif
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_ShowToolbar), AppConfig.ShowToolbar);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_ShowStatusBar), AppConfig.ShowStatusBar);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_ShowInSimpleMode), AppConfig.ShowInSimpleMode);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_AAFont), AppConfig.AntiAliasFont);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_PopupNotifier), AppConfig.PopupNotifier);
 
@@ -155,8 +186,7 @@ void CGeneralPrefPage::OnOK()
 #ifdef USE_DOCKLET
 	AppConfig.ShowTrayIcon = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_ShowTrayIcon));
 #endif
-	AppConfig.ShowToolbar = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_ShowToolbar));
-	AppConfig.ShowStatusBar = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_ShowStatusBar));
+	AppConfig.ShowInSimpleMode = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_ShowInSimpleMode));
 	AppConfig.AntiAliasFont = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_AAFont));
 	AppConfig.PopupNotifier =  gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(m_PopupNotifier));
 	AppConfig.PopupTimeout = (int)gtk_spin_button_get_value( GTK_SPIN_BUTTON(m_PopupTimeout));
